pub trait InfallibleError { }Expand description
A marker trait for error types that will never constructed.
Implementing this on types wrap Infallible and never constructed marks the type as an
infallible error, and implement InfallibleConverter on converters which has the error
type.